@@ -1,5 +1,6 @@
 from __future__ import absolute_import, division, print_function
 import os
+import inspect
 from .record_base import RecordBase
 from .param_base import ParameterBase
 from .utils import GsConstant
@@ -60,6 +61,32 @@ class ControlFile(ParameterBase):
         if abs_path:
             self._make_pths_abs()
 
+    def __getattr__(self, item):
+
+        if item in self.record_names:
+            return self.get_record(item)
+        else:
+            try:
+                return super(ControlFile).__getattribute__(item)
+            except AttributeError:
+                raise AttributeError(
+                    f"ControlFile does not have record {item}"
+                )
+
+    def __setattr__(self, key, value):
+        if key in (
+            "name",
+            "model_dir",
+            "header",
+            "control_file",
+            "_records_list",
+        ):
+            super().__setattr__(key, value)
+        elif key in self.record_names:
+            self.set_values(key, value)
+        else:
+            raise AttributeError(f"PrmsParameters does not have record {key}")
+
     @property
     def records_list(self):
         """
@@ -92,6 +119,7 @@ class ControlFile(ParameterBase):
         with open(control_file, "r") as fid:
             headers = []
             records_list = []
+            param_names = []
             EndOfFile = False
             _read_comments = True
             while True:
@@ -112,6 +140,18 @@ class ControlFile(ParameterBase):
                 data_type = int(fid.readline().strip())
                 values = []
 
+                if field_name in param_names:
+                    msg = (
+                        f"Duplicate parameter {field_name} "
+                        f"found, overwriting with new values"
+                    )
+                    gsflow_io._warning(
+                        msg, inspect.getframeinfo(inspect.currentframe())
+                    )
+                    pidx = param_names.index(field_name)
+                    param_names.pop(pidx)
+                    records_list.pop(pidx)
+
                 # loop over values
                 while True:
 
@@ -134,6 +174,7 @@ class ControlFile(ParameterBase):
                                 values=values,
                                 datatype=data_type,
                             )
+                            param_names.append(field_name)
                             records_list.append(curr_record)
                             break
                         else:
