@@ -67,7 +67,9 @@ class ParameterBase(object):
             return record
         else:
             msg = "The record does not exist..."
-            gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return None
 
     def get_values(self, name):
@@ -87,8 +89,10 @@ class ParameterBase(object):
         record = gsflow_io.find_parameter(name, self._records_list)
 
         if record is None:
-            err = "The record does not exist..."
-            warnings.warn_explicit(err, UserWarning, "param_base.py", 93)
+            msg = "The record does not exist..."
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return None
 
         elif isinstance(record.values, np.ndarray):
@@ -96,7 +100,9 @@ class ParameterBase(object):
 
         else:
             msg = "The values does not exist..."
-            gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return None
 
     def set_values(self, name, values):
@@ -116,7 +122,9 @@ class ParameterBase(object):
 
         if record is None:
             msg = "The record does not exist {}".format(name)
-            gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return None
 
         elif isinstance(record.values, np.ndarray):
@@ -125,7 +133,9 @@ class ParameterBase(object):
 
         else:
             msg = "The record does not exist..."
-            gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return None
 
     def _check_before_add(self, name, values, replace=False):
@@ -158,7 +168,9 @@ class ParameterBase(object):
                 )
             )
             if not replace:
-                gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+                gsflow_io._warning(
+                    msg, inspect.getframeinfo(inspect.currentframe())
+                )
             return False
 
         return True
@@ -207,7 +219,9 @@ class ParameterBase(object):
 
         if name not in self.record_names:
             msg = f"The record does not exist: {name}"
-            gsflow_io._warning(msg, inspect.getframeinfo(inspect.currentframe()))
+            gsflow_io._warning(
+                msg, inspect.getframeinfo(inspect.currentframe())
+            )
             return
 
         for index, nm in enumerate(self.record_names):
