@@ -1,6 +1,6 @@
 from .gsflow_io import find_parameter, get_file_abs, _get_relative_path
 from .constants import GsConstant
-from .rasters import Rasters
+from .rasters import Raster
 from .sfr_renumber import SfrRenumber
 from . import mfreadnam
 from . import gsflow_io
